@@ -2,8 +2,10 @@ from dagster.core.utils import check_dagster_package_version
 
 from .cli import (
     DbtCliOutput,
+    DbtCliResource,
     dbt_cli_compile,
     dbt_cli_docs_generate,
+    dbt_cli_resource,
     dbt_cli_run,
     dbt_cli_run_operation,
     dbt_cli_seed,
@@ -11,6 +13,8 @@ from .cli import (
     dbt_cli_snapshot_freshness,
     dbt_cli_test,
 )
+from .cloud import DbtCloudOutput, DbtCloudResourceV2, dbt_cloud_resource, dbt_cloud_run_op
+from .dbt_resource import DbtResource
 from .errors import (
     DagsterDbtCliFatalRuntimeError,
     DagsterDbtCliHandledRuntimeError,
@@ -20,9 +24,19 @@ from .errors import (
     DagsterDbtError,
     DagsterDbtRpcUnexpectedPollOutputError,
 )
+from .ops import (
+    dbt_compile_op,
+    dbt_docs_generate_op,
+    dbt_ls_op,
+    dbt_run_op,
+    dbt_seed_op,
+    dbt_snapshot_op,
+    dbt_test_op,
+)
 from .rpc import (
-    DbtRpcClient,
     DbtRpcOutput,
+    DbtRpcResource,
+    DbtRpcSyncResource,
     create_dbt_rpc_run_sql_solid,
     dbt_rpc_compile_sql,
     dbt_rpc_docs_generate,
@@ -38,11 +52,12 @@ from .rpc import (
     dbt_rpc_snapshot_and_wait,
     dbt_rpc_snapshot_freshness,
     dbt_rpc_snapshot_freshness_and_wait,
+    dbt_rpc_sync_resource,
     dbt_rpc_test,
     dbt_rpc_test_and_wait,
     local_dbt_rpc_resource,
 )
-from .types import DbtResult, NodeResult, StepTiming
+from .types import DbtOutput
 from .version import __version__
 
 check_dagster_package_version("dagster-dbt", __version__)
@@ -55,13 +70,17 @@ __all__ = [
     "DagsterDbtCliUnexpectedOutputError",
     "DagsterDbtError",
     "DagsterDbtRpcUnexpectedPollOutputError",
+    "DbtResource",
+    "DbtOutput",
     "DbtCliOutput",
-    "DbtResult",
-    "DbtRpcClient",
+    "DbtCliResource",
+    "DbtCloudOutput",
+    "DbtCloudResourceV2",
+    "DbtRpcResource",
+    "DbtRpcSyncResource",
     "DbtRpcOutput",
-    "NodeResult",
-    "StepTiming",
     "create_dbt_rpc_run_sql_solid",
+    "dbt_cli_resource",
     "dbt_cli_compile",
     "dbt_cli_docs_generate",
     "dbt_cli_run",
@@ -70,6 +89,8 @@ __all__ = [
     "dbt_cli_snapshot",
     "dbt_cli_snapshot_freshness",
     "dbt_cli_test",
+    "dbt_cloud_resource",
+    "dbt_cloud_run_op",
     "dbt_rpc_compile_sql",
     "dbt_rpc_docs_generate",
     "dbt_rpc_docs_generate_and_wait",
